

###############################################################################-
# Prepare livestock
###############################################################################-

# # Libraries
library(raster)
library(rgdal)
library(tidyverse)
library(labelled)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000, scipen = 999)

# Sublocations
subl_all <- readRDS("outputs/sublocations_kenya.rds")
subl_ki <- subl_all[subl_all$COUN_NM == "KITUI", ]
subl_ki <-  subl_ki[c("SUBL_ID_PaHC2009", "SUBL_ID", "nrHh")]



# Data and source --------------------------------------------------------------

# Source: Kenya PaHC2009 

# Glossary (Census Volume 1C.pdf)
# - Exotic Cattle: Refers to cattle whether pure (non-indigenous) or 
#   improved breeds
# - Indigenous Cattle: Refers to the local breeds of cattle such as the Zebu and 
#   Boran breeds, among others


# Share of crop cultivating households -----------------------------------------

# Calculate the share of households that cultivate crops
# The assumption is that ...
# - ... all households in rural areas cultivate crops
# - ... 50% of the households in peri-urban areas cultivate crops
# - ... no households in urban areas cultivate crop
hh <- read_rds("inputs/pahc2009/01_prepareData/hh.rds")
shrAgric <- hh %>% 
  filter(SUBL_ID %in% unique(subl$SUBL_ID_PaHC2009)) %>% 
  select(SUBL_ID, EATYPE,
         HH_ID) %>% 
  mutate(EATYPE = to_character(EATYPE)) %>% 
  group_by(SUBL_ID, EATYPE) %>% 
  count() %>% 
  mutate(shr = n / sum(n)) %>% 
  group_by(shr) %>% 
  select(-n) %>% 
  spread(key = EATYPE, value = shr, fill = 0) %>% 
  transmute(SUBL_ID, agricShr = `PERI-URBAN` * 0.5 + RURAL * 1 + URBAN * 0) 
agricHh <- merge(subl_ki, shrAgric, by.x = "SUBL_ID_PaHC2009", by.y = "SUBL_ID")
agricHh$agricShr[is.na(agricHh$agricShr)] <- 0 # Replace NA with 0


# Calculate the number of households
agricHh$agricHh <- agricHh$nrHh * agricHh$agricShr
# spplot(agricHh["agricHh"])

saveRDS(agricHh, "outputs/01_supply/01_inputs/agricHh.rds")




# Check ------------------------------------------------------------------------

library(tidyverse)
library(labelled)
library(haven)
library(splitstackshape)


# Load identification data and create unique hh ID
#     District codes
#     - Kitui: 403
#     - Mwingi: 410
#     Source: "KIHBS 2005 Interviewers Manual"
ident <- read_sav("inputs/ihbs2005/inputs/Section A Identification.sav")
ident <- ident %>% 
  select(district, id_clust, id_hh, rurban, hhsize) %>% 
  filter(district %in% c(403, 410))

# Load data on argicultural holdings, limit to kitui and replicate for weighting
ah <- read_sav("inputs/ihbs2005/inputs/Section N Agriculture Holding.sav"); ah
ah <- ah %>% 
  filter(id_clust %in% ident$id_clust)
ah <- expandRows(dataset = ah, count = "weight", count.is.col = T)
ah


share <- ah %>% 
  transmute(farming = to_character(n01)) %>% 
  group_by(farming) %>% 
  count() %>% 
  mutate(shr = n / sum(n))
share








