
###############################################################################-
# Alternative wood demands
###############################################################################-

# # Libraries
library(raster)
library(rgdal)
library(tidyverse)
library(labelled)
# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000)


# Construction wood  -----------------------------------------------------------

# Drigo et al. 2015
# - Construction material: 
#   In the absence of adequate references, the use of construction material4 
#   used by rural and urban households was estimated, tentatively, on the basis 
#   of estimates used in Rwanda (14), Sudan (15) and Mozambique (16), in the 
#   context previous WISDOM analyses. The values applied are 19.2 od kg of wood 
#   person-1 year-1 in rural areas and 5.6 od kg of wood person-1 year-1 in 
#   urban areas


# Load data
woodDemConstr <- readRDS("outputs/pop_kitui.rds"); woodDemConstr
x <- readRDS("outputs/sublocations_kenya.rds")
head(x)

# Get shares of urbanisation type
readRDS("inputs/pahc2009/01_prepareData/shp_joinReady.rds")
hh <- read_rds("inputs/pahc2009/01_prepareData/hh.rds"); hh
dta <- hh %>% 
  select(SUBL_ID, EATYPE) %>% 
  transmute(SUBL_ID, EATYPE = to_character(EATYPE)) %>% 
  group_by(SUBL_ID, EATYPE) %>% 
  count() %>% 
  mutate(shr = n /sum(n)) %>% 
  select(-n) %>% 
  ungroup() %>% 
  spread(key = EATYPE, value = shr, fill = 0) %>% 
  group_by(SUBL_ID) %>% 
  summarise_all(sum) 
dta

# Calculate population according to urbanisation type
woodDemConstr <- merge(x = woodDemConstr, y = dta, 
                      by.x = "SUBL_ID_PaHC2009", by.y = "SUBL_ID")
woodDemConstr@data[is.na(woodDemConstr$`PERI-URBAN`), ]$`PERI-URBAN` <- 0
woodDemConstr@data[is.na(woodDemConstr$RURAL), ]$RURAL <- 0
woodDemConstr@data[is.na(woodDemConstr$URBAN), ]$URBAN <- 0
woodDemConstr$`PERI-URBAN` <- woodDemConstr$pop * woodDemConstr$`PERI-URBAN`
woodDemConstr$RURAL <- woodDemConstr$pop * woodDemConstr$RURAL
woodDemConstr$URBAN <- woodDemConstr$pop * woodDemConstr$URBAN

# Define annual wood consuption per year and urbanisaiton type
consKgPerPers <- c(kgYrUrbanpers = 5.6, 
                 kgYrRuralpers = 19.2, 
                 kgYrPeriurbpers = 12.4)
consTonsPerPers <- consKgPerPers / 1000
names(consTonsPerPers) <- c("tYrUrbanpers", "tYrRuralpers", "tYrPeriurbpers")

# Calculate total demand of costruction wood
woodDemConstr$woodCons_tYr <-
  woodDemConstr$RURAL * consTonsPerPers["tYrRuralpers"] + 
  woodDemConstr$`PERI-URBAN` * consTonsPerPers["tYrPeriurbpers"] + 
  woodDemConstr$URBAN * consTonsPerPers["tYrUrbanpers"]
woodDemConstr



# Firewood ---------------------------------------------------------------------

# Source!!!!!!!!!!!!!!!!!!!!

alterWooddem_firewood <- 
  readRDS("outputs/01_supply/02_models/charcoal/accessMai.rds")
alterWooddem_firewood$firewood_t <- alterWooddem_firewood$acceMai_t * 0.1


# Miscellaneous ----------------------------------------------------------------

# Source!!!!!!!!!!!!!!!!!!!!

alterWooddem_misc <- 
  readRDS("outputs/01_supply/02_models/charcoal/accessMai.rds")
alterWooddem_misc$misc_t <- alterWooddem_misc$acceMai_t * 0.2



# Total demand -----------------------------------------------------------------

# Load and reduce layers to relevant variable 
subl <- readRDS("outputs/pop_kitui.rds")
subl <- subl[c("SUBL_ID", "SUBL_ID_PaHC2009")]
alterWooddem_construct <- woodDemConstr[c("SUBL_ID_PaHC2009", "woodCons_tYr")]
alterWooddem_firewood <- alterWooddem_firewood[c("SUBL_ID_PaHC2009", 
                                                 "firewood_t")]
alterWooddem_misc <- alterWooddem_misc[c("SUBL_ID_PaHC2009", "misc_t")]

# Merge layers
alternWooddem <- Reduce(function(x, y) merge(x, y), 
                        list(subl, 
                             alterWooddem_construct, 
                             alterWooddem_firewood, 
                             alterWooddem_misc))

# Calculate total of alternative demands
alternWooddem$alterWooddem_tot_t <- 
  rowSums(alternWooddem[, !(names(alternWooddem) %in% 
                              c("SUBL_ID_PaHC2009", "SUBL_ID"))]@data)
head(alternWooddem)

# Export
saveRDS(alternWooddem, "outputs/01_supply/01_inputs/alterWooddemands.rds")










