
###############################################################################-
# Crop area
###############################################################################-

# # Libraries
library(raster)
library(rgdal)
library(readxl)
library(rgeos)


# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000, scipen = 999)

subl <- readRDS("outputs/sublocations_kenya.rds")
subl <- subl[subl$COUN_NM == "KITUI", 
             c("SUBL_ID_PaHC2009", "SUBL_ID", "pop", "nrHh")]



# Data and source --------------------------------------------------------------

# Lulc map: Africover
#   http://www.fao.org/geonetwork/srv/en/metadata.show?id=38098&currTab=simple



# Processing -------------------------------------------------------------------

# Load, reproject, and clip landuse data
lulc <- readOGR(dsn = "inputs/africover/ke_landcover_ge/ke-landcover-ge.shp", 
                layer =  "ke-landcover-ge",
                stringsAsFactors = F, disambiguateFIDs = T, verbose = T)
lulc <- spTransform(lulc, subl@proj4string)
lulc <- crop(lulc, subl)
lulc <- lulc[c("USERLABEL", "CODE1", "LCCCODE", "LCCLEVEL")]
str(lulc@data); head(lulc[order(lulc$CODE1), ])
lulc$ID <- row.names(lulc)

# Get legend table
lut <- read_excel(
  "inputs/africover/ke_landcover_ge/Kenya Legend - LCCS Import file.xls")
lut$LC <- ifelse(lut$LC != "Error", substr(lut$LC, 2, length(lut$LC)), lut$LC)
str(lut); head(lut[order(lut$MapCode), ])

# Add lengend to map layer 
map <- lulc
tabl <- merge(map@data, lut, by.x = "CODE1", by.y = "MapCode", all.x = T)
str(tabl); head(tabl)
map <- merge(map, tabl, by = "ID")
map <- map["LC"]

# Create binary crop layer 
map$crops <- "no"
map[map$LC == "Herbaceous Crops", "crops"] <- "yes"
map
# plot(map[map$crops == "yes", ])

# Interset sublocations with land use and calculat the area
subl$areaSubl_km2 <- gArea(subl, byid = T) / 1000000
inters <- raster::intersect(x = subl, y = map)

# Calculate area of crop cultivation areas
inters$cropArea_km2 <- gArea(inters, byid = T) / 1000000
inters[inters$crops == "no", "cropArea_km2"] <- 0

# Calculate the share of the crop area within the sublocation compared to the 
#   entire crop area within the county
inters$cropArea_shrTot <- 0
inters[inters$crops == "yes", "cropArea_shrTot"] <- 
  inters[inters$crops == "yes", ]$cropArea_km2 / 
  sum(inters[inters$crops == "yes", ]$cropArea_km2)

# Plot crop cultivation areas
# spplot(inters["cropArea_shrTot"])
# plot(subl)
# plot(inters[inters$crops == "yes", ], add = T, col = "red")

# Aggregate values to sublocation level
inters <- aggregate(x = inters, 
                  by = "SUBL_ID", 
                  sums = list(list(sum, "cropArea_shrTot"), 
                              list(sum, "cropArea_km2")))

sum(inters$cropArea_km2)



maizePlots_ha <- 93600 # County Government of Kitui (2014)
cropPlots_ha <- 295937  # County Government of Kitui (2014)
inters$maizeArea_km2 <- maizePlots_ha / 100 * inters$cropArea_shrTot
inters$cropArea_km2 <- cropPlots_ha / 100 * inters$cropArea_shrTot



# Export -----------------------------------------------------------------------
saveRDS(inters, "outputs/01_supply/01_inputs/shrCropArea.rds")
writeOGR(obj = inters[!names(inters) %in% "SUBL_ID"], 
         dsn = "outputs/01_supply/01_inputs/shrCropArea.shp", 
         layer = "shrCropArea", 
         driver = "ESRI Shapefile", 
         overwrite_layer = T)




