

###############################################################################-
# Biogas model
###############################################################################-

# # Libraries
library(raster)
library(rgdal)
library(dplyr)
library(tidyr)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000, scipen = 999)
rm(list = ls())

subl <- readRDS("outputs/pop_kenya.rds")



# Dung -------------------------------------------------------------------------

# import
dungProductivity <- readRDS("outputs/01_supply/01_inputs/dungProductivity.rds")
livestock <- readRDS("outputs/01_supply/02_models/biogas/livestock.rds")
dung <- livestock
head(dung)

# Calculate the dung produced by the different livestock types
dung$dungExoCat_tYr <- 
  dung$exoCattle_nr * dungProductivity["freshWaste_tYrExocow"]
dung$dungIndCat_tYr <- 
  dung$indCattle_nr * dungProductivity["freshWaste_tYrIndcow"]
dung$dungPigs_tYr <- 
  dung$pigs_nr * dungProductivity["freshWaste_tYrPig"]

dung$dung_tYr <- dung$dungIndCat_tYr + dung$dungExoCat_tYr + dung$dungPigs_tYr
head(dung)

# Export
saveRDS(dung, "outputs/01_supply/02_models/biogas/dung.rds")



# Accessible dung --------------------------------------------------------------

# Import
accessDung <- readRDS("outputs/01_supply/02_models/biogas/dung.rds")
accessShares <- readRDS("outputs/01_supply/01_inputs/dungAccessibility.rds")

# Calculate the accessible amount of dung
accessDung$accDungExoCat_tYr <- 
  accessDung$dungExoCat_tYr * accessShares["exotCatt"]
accessDung$accDungIndCat_tYr <- 
  accessDung$dungIndCat_tYr * accessShares["indegCatt"]
accessDung$accDungPigs_tYr <- 
  accessDung$dungPigs_tYr * accessShares["pigs"]

# Export
saveRDS(accessDung, "outputs/01_supply/02_models/biogas/accessDung.rds")



# Slurry -----------------------------------------------------------------------

# Import
slurry <- readRDS("outputs/01_supply/02_models/biogas/accessDung.rds")
accessWater <- readRDS("outputs/01_supply/01_inputs/accessWater.rds")
ratioWatertoSlurry <- 
  readRDS("outputs/01_supply/01_inputs/ratioWaterToSlurry.rds")

#  Multiply produced dung with share of households with access to water (< min) 
#  and at the ammount of water to get the amount of slurry
slurry$accessWater <- accessWater[accessWater$accessWater == "yes", ]$shr
slurry$slurryExocat_tYr <- 
  (slurry$accDungExoCat_tYr * slurry$accessWater) * (1 + ratioWatertoSlurry)
slurry$slurryIndCat_tYr <- 
  (slurry$accDungIndCat_tYr * slurry$accessWater) * (1 + ratioWatertoSlurry)
slurry$slurryPigs_tYr <- 
  (slurry$accDungPigs_tYr * slurry$accessWater) * (1 + ratioWatertoSlurry)
slurry$slurry_tYr <- 
  slurry$slurryExocat_tYr + slurry$slurryPigs_tYr + slurry$slurryIndCat_tYr
head(slurry)

# Export
saveRDS(slurry, "outputs/01_supply/02_models/biogas/slurry.rds")



# Biogas ---------------------------------------------------------------------

# Import
slurry <- readRDS("outputs/01_supply/02_models/biogas/slurry.rds")
biogas <- slurry
ratioWatertoSlurry <- 
  readRDS("outputs/01_supply/01_inputs/ratioWaterToSlurry.rds")
ratioDungToBiogas <- 
readRDS("outputs/01_supply/01_inputs/ratioDungToBiogas.rds")
comment(ratioDungToBiogas)

# Convert the dung (from the slurry) to biogas
head(biogas)
biogas$biogs_exoCat_m3Yr <- 
  biogas$slurryExocat_tYr / (1 + ratioWatertoSlurry) * ratioDungToBiogas["exoCat"]
biogas$biogs_indiCat_m3Yr <- 
  biogas$slurryIndCat_tYr / (1 + ratioWatertoSlurry) * ratioDungToBiogas["indCat"]
biogas$biogs_pigs_m3Yr <- 
  biogas$slurryPigs_tYr / (1 + ratioWatertoSlurry) * ratioDungToBiogas["pigs"]
biogas$biogas_m3Yr <- 
  biogas$biogs_exoCat_m3Yr + biogas$biogs_indiCat_m3Yr + biogas$biogs_pigs_m3Yr
head(biogas)

# Export
saveRDS(biogas, "outputs/01_supply/02_models/biogas/biogas.rds")




# Household equivalents --------------------------------------------------------

# Import
biogas <- readRDS("outputs/01_supply/02_models/biogas/biogas.rds")
fuelDem <- readRDS("outputs/01_supply/01_inputs/biogasDemand.rds")
fuelDem

# Calculate number of potential meal equivalents base on the biogas supply and 
#  the biogas consumption for cooking one meal

fuelDem_biogasM3Yr <- fuelDem["biogasDemand_m3HhYr"]; fuelDem_biogasM3Yr
biogas$biogasHh <- biogas$biogas_m3Yr / fuelDem_biogasM3Yr

# Export
head(biogas)
saveRDS(biogas, "outputs/01_supply/02_models/biogas/biogasHh.rds")







# Result overview --------------------------------------------------------------
# Create a table with all relevant intermediate results

subl <- readRDS("outputs/sublocations_kenya.rds")
subl <- subl[subl$COUN_NM == "KITUI", ]
subl <- subl[c("SUBL_ID_PaHC2009", "SUBL_ID", "Area_km2", "pop", "nrHh")]

livestock <- readRDS("outputs/01_supply/02_models/biogas/livestock.rds")
livestock <- livestock[c("SUBL_ID", 
                         "exoCattle_meanHh", "indCattle_meanHh", "pigs_meanHh", 
                         "exoCattle_nr", "indCattle_nr", "pigs_nr")]

dung <- readRDS("outputs/01_supply/02_models/biogas/dung.rds")
dung <- dung[c("SUBL_ID", "dungExoCat_tYr", "dungIndCat_tYr", "dungPigs_tYr")]

accDung <- readRDS("outputs/01_supply/02_models/biogas/accessDung.rds")
accDung <- accDung[c("SUBL_ID", "accDungExoCat_tYr", "accDungIndCat_tYr", 
                     "accDungPigs_tYr")]

slurr <- readRDS("outputs/01_supply/02_models/biogas/slurry.rds")
slurry <- slurr[c("SUBL_ID", "accessWater", "slurryExocat_tYr", 
                  "slurryIndCat_tYr", "slurryPigs_tYr")]

biogas <- readRDS("outputs/01_supply/02_models/biogas/biogas.rds")
biogas <- biogas[c("SUBL_ID", "biogs_exoCat_m3Yr", "biogs_indiCat_m3Yr", 
                   "biogs_pigs_m3Yr", "biogas_m3Yr")]

housholds <- readRDS("outputs/01_supply/02_models/biogas/biogasHh.rds")
housholds <- housholds[c("SUBL_ID", "biogasHh")]


# Bring all together in one SPDF
all <- Reduce(function(x, y) merge(x, y, by = "SUBL_ID"), 
              list(subl, livestock, dung, accDung, slurry, biogas, housholds))
all
head(all)


saveRDS(all, "outputs/01_supply/02_models/biogas/allResults.rds")
writeOGR(all[, !names(all) %in% c("SUBL_ID_PaHC2009")], 
         "outputs/01_supply/02_models/biogas/allResults.shp", "allResults", 
         "ESRI Shapefile", overwrite_layer = T)



# Density results --------------------------------------------------------------

# Import
all <- readRDS("outputs/01_supply/02_models/biogas/allResults.rds")

# Calculate density values (amount per sqkm) of results
perVar <- c("SUBL_ID_PaHC2009", "SUBL_ID", "Area_km2")
map <- all[, names(all) %in% perVar]
dta <- all[, !names(all) %in% perVar]@data
dta <- sapply(dta, function(x) x / all$Area_km2)
dens <- cbind(map, dta)

# Export
saveRDS(dens, "outputs/01_supply/02_models/biogas/allResults_dens.rds")
writeOGR(dens[, !names(dens) %in% c("SUBL_ID")]
         , "outputs/01_supply/02_models/biogas/allResults_dens.shp", 
         "allResults", "ESRI Shapefile", overwrite_layer = T)



# Check -----------------------------------------------------------------------

# Get data
bgMap <- readRDS("outputs/01_supply/02_models/biogas/allResults.rds")
bgDta <- tbl_df(bgMap); bgDta
bgAgg <- bgDta %>%
  summarise_at(vars(Area_km2:biogasHh), funs(sum))
bgAgg
bgAgg %>% 
  gather(variable, value) %>% 
  print(n = 100)

# Dung per animal
bgAgg$dung_perExoCowYr <- bgAgg$dungExoCat_tYr / bgAgg$exoCattle_nr 
bgAgg$dung_perExoCowYr # Correct
bgAgg$dung_perIndiCowYr <- bgAgg$dungIndCat_tYr / bgAgg$indCattle_nr 
bgAgg$dung_perIndiCowYr # Correct
bgAgg$dung_perPigYr <- bgAgg$dungPigs_tYr / bgAgg$pigs_nr
bgAgg$dung_perPigYr # Correct

# Access to dung
bgAgg$accToDungExoCat_shr <- bgAgg$accDungExoCat_tYr / bgAgg$dungExoCat_tYr
bgAgg$accToDungExoCat_shr # Correct
bgAgg$accToDungIndCat_shr <- bgAgg$accDungIndCat_tYr / bgAgg$dungIndCat_tYr
bgAgg$accToDungIndCat_shr # Correct
bgAgg$accToDungPigs_shr <- bgAgg$accDungPigs_tYr / bgAgg$dungPigs_tYr 
bgAgg$accToDungPigs_shr# Correct

# Access to water
bgAgg$accToWater_shr <- sum(bgDta$accessWater * bgDta$pop) / sum(bgDta$pop)
bgAgg$accToWater_shr# Correct

# Slurry ratio (water access not accounted for)
bgAgg$slurryExocat_tYr / bgAgg$accDungExoCat_tYr / 2 # Correct
bgAgg$slurryIndCat_tYr / bgAgg$accDungIndCat_tYr / 2# Correct
bgAgg$slurryPigs_tYr / bgAgg$accDungPigs_tYr / 2 # Correct

# Biogas per dung
bgAgg$biogasPerDung_exoCat <- 
  bgAgg$biogs_exoCat_m3Yr / (bgAgg$slurryExocat_tYr / 2) 
bgAgg$biogasPerDung_exoCat # Correct
bgAgg$biogasPerDung_indiCat <- 
  bgAgg$biogs_indiCat_m3Yr / (bgAgg$slurryIndCat_tYr / 2) 
bgAgg$biogasPerDung_indiCat # Correct
bgAgg$biogasPerDung_pigs <- 
  bgAgg$biogs_pigs_m3Yr / (bgAgg$slurryPigs_tYr / 2) 
bgAgg$biogasPerDung_pigs# Correct

# Biogas per hh
bgAgg$biogasDemPerHd <- bgAgg$biogas_m3Yr / bgAgg$biogasHh; 
bgAgg$biogasDemPerHd # Correct


bgAgg %>% 
  gather(var, val) %>% 
  print(n = 40)


# Household balance ------------------------------------------------------------

# How many livestock would a hh need to cover its energy demand? 
biogasDem_lD <- 657

# Exotic cows
dungProd_exoCat_kgD <- 25.75
dungAccess_exoCat_shr <- 1
accDung_exoCat_kgD <-  dungProd_exoCat_kgD * dungAccess_exoCat_shr; 
accDung_exoCat_kgD

biogasPerDung_exoCat_lKg <- 100
biogasProd_exoCat_lD <- accDung_exoCat_kgD * biogasPerDung_exoCat_lKg; 
biogasProd_exoCat_lD

coverRate_exoCat <- biogasProd_exoCat_lD / biogasDem_lD; coverRate_exoCat
# That would mean an exotic cow could cover the energy demand of almost 4 hh

# Indig cows
dungProd_indiCat_kgD <- 9.98
duncAccess_indiCat_shr <- 0.4
accDunk_indiCat_kgD <- dungProd_indiCat_kgD * duncAccess_indiCat_shr; 
accDunk_indiCat_kgD

biogasPerDung_indiCat_lKg <- 32
biogasProd_indiCat_lD <- accDunk_indiCat_kgD * biogasPerDung_indiCat_lKg; 
biogasProd_indiCat_lD

coverRate_indiCat <- biogasProd_indiCat_lD / biogasDem_lD; coverRate_indiCat
# that would mean a hh would need 5 indigenous cows to cover the energy demand

# Pigs
dungProd_pigs_kgD <- 2.3
duncAccess_pigs_shr <- 1
accDunk_pigs_kgD <- dungProd_pigs_kgD * duncAccess_pigs_shr; 
accDunk_pigs_kgD

biogasPerDung_pigs_lKg <- 81
biogasProd_pigs_lD <- accDunk_pigs_kgD * biogasPerDung_pigs_lKg; 
biogasProd_pigs_lD

coverRate_pigs <- biogasProd_pigs_lD / biogasDem_lD; coverRate_pigs
# that would mean a hh would need 4 pigs to cover the energy demand



# http://www.nation.co.ke/business/seedsofgold/One-well-fed-cow-produce-enough-biogas-for-a-small-scale-farm/2301238-3222038-iewm8yz/index.html






# ------------------------------------------------------------------------------
rm(list = ls())

















