

###############################################################################-
# Charcoal model
###############################################################################-

# # Libraries
library(raster)
library(rgdal)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000)
rm(list = ls())



# MAI --------------------------------------------------------------------------

# Load data
subl <- readRDS("outputs/sublocations_kenya.rds")
subl <- 
subl[subl$COUN_NM == "KITUI", c("SUBL_ID_PaHC2009", "SUBL_ID", "Area_km2")]
mai <- stack("outputs/01_supply/01_inputs/woodstock.grd")
source("scripts/01_supply/01_inputs/maiWood.R")

# Calculate the share of the MAI from the woodstock
mai$maiShr_tPix <- getMaiShrFromAbwbm(mai$wbm_tPix)
mai$maiShr_tHa <- getMaiShrFromAbwbm(mai$wbm_mean_tHa)

# Calculate the mai per ha and pixel
mai$mai_tHa <- mai$wbm_mean_tHa * mai$maiShr_tHa
mai$mai_tPix <- mai$mai_tHa  * mai$pixArea_ha

# Aggregate  mai to sublocations
mai_subl <- raster::extract(x = mai[[c("mai_tPix")]], 
                            y = spTransform(subl, mai@crs), 
                            fun = sum, 
                            na.rm = T, 
                            sp = T)
names(mai_subl)[names(mai_subl) == "mai_tPix"] <- "mai_t"
mai_subl$mai_tKm2 <-  mai_subl$mai_t / mai_subl$Area_km2

# Aggregate mai share to sublocations
mai_subl2 <- raster::extract(x = mai[[c("maiShr_tHa")]], 
                            y = spTransform(subl, mai@crs), 
                            fun = mean, 
                            na.rm = T, 
                            sp = T)

# Combine results to one single SPDF
reslt <- merge(mai_subl, mai_subl2[c("SUBL_ID_PaHC2009", "maiShr_tHa")])

# Export
writeRaster(mai, "outputs/01_supply/02_models/charcoal/maiWoodyBiomass.grd")
saveRDS(reslt, "outputs/01_supply/02_models/charcoal/maiWoodyBiomass.rds")

# Check overall MAI
ws <- readRDS("outputs/01_supply/02_models/charcoal/woodstock.rds")
sum(reslt$mai_t) / sum(ws$wbm_t)
# 4% seems reasonable 
# Compare  
# - Drigo et al 2014: 0.0374 (26496 / 708000)
# - NAFORMA: 0.07 Cultivated areas; 0.01 non-cultivated areas; 0.23 forest plant.
#  - Day et al 2014: annual increment of woody biomass is approximately 3–4% in
#    mature stands (Frost 1996)



# Accessible MAI ---------------------------------------------------------------

# Load data
accessMai <- stack("outputs/01_supply/02_models/charcoal/maiWoodyBiomass.grd")
ea <- readRDS("outputs/01_supply/01_inputs/exclusionAres.rds")
ea <- spTransform(ea, accessMai@crs)
plot(accessMai[["mai_tHa"]]); plot(ea, add = T)

# Remove protected areas from woodstock
accessMai <- mask(x = accessMai, 
                  mask = ea, 
                  inverse = T, 
                  updatevalue = 0)
writeRaster(accessMai, "outputs/01_supply/02_models/charcoal/accessMai.grd")

  # Aggregate to sublocations
subl <- readRDS("outputs/sublocations_kenya.rds")
subl <- 
  subl[subl$COUN_NM == "KITUI", c("SUBL_ID_PaHC2009", "SUBL_ID", "Area_km2")]
accessMai_subl <- raster::extract(x = accessMai$mai_tPix, 
                                  y = spTransform(subl, accessMai@crs), 
                                  fun = sum, 
                                  na.rm = T, 
                                  sp = T)
names(accessMai_subl)[names(accessMai_subl) == "mai_tPix"] <- "acceMai_t"
accessMai_subl$acceMai_tHa <- 
  accessMai_subl$acceMai_t / (accessMai_subl$Area_km2 * 100) 

# Export
saveRDS(accessMai_subl, "outputs/01_supply/02_models/charcoal/accessMai.rds")



# Available wood ---------------------------------------------------------------

availWood <- readRDS("outputs/01_supply/02_models/charcoal/accessMai.rds")
availWood <- availWood[c("SUBL_ID_PaHC2009", "SUBL_ID", "acceMai_t")]
source("scripts/01_supply/01_inputs/alternativeWoodDemands.R")
alternWooddem <- readRDS("outputs/01_supply/01_inputs/alterWooddemands.rds")
alternWooddem <- alternWooddem[c("SUBL_ID_PaHC2009", "alterWooddem_tot_t")]
availWood <- merge(x = availWood, 
                   y = alternWooddem, 
                   by = "SUBL_ID_PaHC2009")

# Calculate the remaining available wood (for charcoal)
availWood$availWood_t <- availWood$acceMai_t - availWood$alterWooddem_tot_t

# Export
saveRDS(availWood, "outputs/01_supply/02_models/charcoal/availWood.rds")



# Charcoal ---------------------------------------------------------------------

charcoal <- readRDS("outputs/01_supply/02_models/charcoal/availWood.rds")
charcoal <- charcoal[c("SUBL_ID_PaHC2009", "SUBL_ID", "availWood_t")]
kilnEff <- readRDS("outputs/01_supply/01_inputs/kilnEfficiency.rds")

charcoal <- merge(charcoal, kilnEff)
charcoal$charcoal_t <- charcoal$availWood_t * charcoal$kilnEffic
charcoal <- charcoal[, c("SUBL_ID", "charcoal_t")]

saveRDS(charcoal, "outputs/01_supply/02_models/charcoal/charcoal.rds")


# Meal equivalents -------------------------------------------------------------

subl <- readRDS("outputs/01_supply/02_models/charcoal/charcoal.rds")
fuelDem <- readRDS("outputs/01_supply/01_inputs/charcoalDemand.rds")

subl$charcoalHh <- subl$charcoal_t / fuelDem["charcoalDemand_tHhYr"]

# Export
saveRDS(subl, "outputs/01_supply/02_models/charcoal/charcoalHh.rds")



# Result overview --------------------------------------------------------------
# Create a table with all relevant intermediate results

subl <- readRDS("outputs/sublocations_kenya.rds")
subl <- subl[subl$COUN_NM == "KITUI", ]
subl <- subl[c("SUBL_ID_PaHC2009", "SUBL_ID", "Area_km2", "pop", "nrHh")]

woodstock <- readRDS("outputs/01_supply/02_models/charcoal/woodstock.rds")
woodstock <- woodstock[c("SUBL_ID", "wbm_t")]

mai <- readRDS("outputs/01_supply/02_models/charcoal/maiWoodyBiomass.rds")
mai <- mai[c("SUBL_ID", "mai_t")]

accessMai <- readRDS("outputs/01_supply/02_models/charcoal/accessMai.rds")
accessMai <- accessMai[c("SUBL_ID", "acceMai_t")]

availMai <- readRDS("outputs/01_supply/02_models/charcoal/availWood.rds")
availWood <- availMai[c("SUBL_ID", "availWood_t")]

charcoal <- readRDS("outputs/01_supply/02_models/charcoal/charcoal.rds")
charcoal <- charcoal[c("SUBL_ID", "charcoal_t")]

households <- readRDS("outputs/01_supply/02_models/charcoal/charcoalHh.rds")
households <- households[c("SUBL_ID", "charcoalHh")]

# Bring all together in one SPDF
all <- Reduce(function(x, y) merge(x, y, by="SUBL_ID"), 
              list(subl, woodstock, mai, accessMai, availWood, charcoal, 
                   households)); all
head(all)

saveRDS(all, "outputs/01_supply/02_models/charcoal/allResults.rds")
writeOGR(all[, !names(all) %in% "SUBL_ID"], 
         "outputs/01_supply/02_models/charcoal/allResults.shp", 
         "allResults", "ESRI Shapefile", overwrite_layer = T)



# Density results --------------------------------------------------------------

# Import
all <- readRDS("outputs/01_supply/02_models/charcoal/allResults.rds")

# Calculate density values (amount per sqkm) of results
perVar <- c("SUBL_ID_PaHC2009", "SUBL_ID", "Area_km2")
map <- all[, names(all) %in% perVar]
dta <- all[, !names(all) %in% perVar]@data
dta <- sapply(dta, function(x) x / all$Area_km2)
dens <- cbind(map, dta)

# Export
saveRDS(dens, "outputs/01_supply/02_models/charcoal/allResults_dens.rds")
writeOGR(dens[, !names(dens) %in% "SUBL_ID"], 
         "outputs/01_supply/02_models/charcoal/allResults_dens.shp", 
         "allResults", "ESRI Shapefile", overwrite_layer = T)



# Check ------------------------------------------------------------------------
ccMap <- readRDS("outputs/01_supply/02_models/charcoal/allResults.rds")
ccDta <- tbl_df(ccMap); ccDta
ccAgg <- ccDta %>% 
  summarise_at(vars(Area_km2:charcoalHh), funs(sum)) 
ccAgg

# Density of above-ground woody biomass
ccAgg$wbmDens_tKm2 <-  ccAgg$wbm_t / ccAgg$Area_km2
ccAgg$wbmDens_tKm2 # Seems reasonable: -> 
#  References:
# - Avitabile et al 2012
# - Wu et al. 2013
# - Baccini et al 2008
# - Odipo et al 2016


# Increment rate (% of woodstock per year)
ccAgg$incremRate_shr <- ccAgg$mai_t / ccAgg$wbm_t 
ccAgg$incremRate_shr # Correct (use as input) -> but is that a good input value
# References:
# - Drigo (2005): 2.5% of stocking


# Amount of the accessible biomass (loss through exlusion areas)
ccAgg$exclusAreasLoss <- ccAgg$acceMai_t / ccAgg$mai_t
ccAgg$exclusAreasLoss # Seems reasonable

# Imact of alternative demands
ccAgg$alternDemLoss <- ccAgg$availWood_t / ccAgg$acceMai_t 
ccAgg$alternDemLoss 

# Kiln efficiency
ccAgg$kilnEffic_shr <- ccAgg$charcoal_t / ccAgg$availWood_t
ccAgg$kilnEffic_shr # Correct

# Charcoal demand per household
ccAgg$ccDemand_tHhYr <- ccAgg$charcoal_t / ccAgg$charcoalHh
ccAgg$ccDemand_tHhYr # Correct






# ------------------------------------------------------------------------------
rm(list = ls())













