

###############################################################################-
# Crop residue model
###############################################################################-

# # Libraries
library(raster)
library(rgdal)
library(tidyverse)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000)
rm(list = ls())


subl <- readRDS("outputs/sublocations_kenya.rds")
subl <- subl[subl$COUN_NM == "KITUI", c("SUBL_ID_PaHC2009", "SUBL_ID", "pop", 
                                        "nrHh")]
kitui <- readRDS("outputs/pop_kitui.rds")



# Maize yield ------------------------------------------------------------------

# Import
subl <- readRDS("outputs/01_supply/01_inputs/shrCropArea.rds")
maizeYield <- readRDS("outputs/01_supply/01_inputs/maizeProduction_kitui.rds")

# Downscale total maize yield to the sublcations according to the share of 
#   agricultural areas 
subl$maizeYield_t <- subl$cropArea_shrTot * maizeYield["maize_t"]

# Export
saveRDS(subl, "outputs/01_supply/02_models/cropresidues/maizeYield.rds")



# Stover -----------------------------------------------------------------------

# Import
subl <- readRDS("outputs/01_supply/02_models/cropresidues/maizeYield.rds")
maizeYldToFeedstRatio_shr <- 
  readRDS("outputs/01_supply/01_inputs/maizeYieldToFeedstockRatio.rds")

# Get residues from maize yield
subl$maizeResidues_t <- 
  subl$maizeYield_t * maizeYldToFeedstRatio_shr["maizeYieldToCobRatio"]

# Export
saveRDS(subl, "outputs/01_supply/02_models/cropresidues/maizeResidues.rds")



# Meals ------------------------------------------------------------------------

# Import
subl <- readRDS("outputs/01_supply/02_models/cropresidues/maizeResidues.rds")
maizeBriqDemand <- readRDS("outputs/01_supply/01_inputs/maizeBriqDemand.rds")

# Calculate weight of cobs
subl$maizeHh <- 
  subl$maizeResidues_t / maizeBriqDemand["maizeBriqDem_tHhYr"]

# Export
head(subl)
saveRDS(subl, "outputs/01_supply/02_models/cropresidues/maizeHh.rds")



# Result overview --------------------------------------------------------------
# Create a table with all relevant intermediate results

subl <- readRDS("outputs/sublocations_kenya.rds")
subl <- subl[subl$COUN_NM == "KITUI", ]
subl <- subl[c("SUBL_ID_PaHC2009", "SUBL_ID", "Area_km2", "pop", "nrHh")]

cropArea <- readRDS("outputs/01_supply/01_inputs/shrCropArea.rds")
cropArea <- cropArea[c("SUBL_ID", "cropArea_km2", "maizeArea_km2")]

yield <- readRDS("outputs/01_supply/02_models/cropresidues/maizeYield.rds")
yield <- yield[c("SUBL_ID", "maizeYield_t")]

residues <- 
  readRDS("outputs/01_supply/02_models/cropresidues/maizeResidues.rds")
residues <- residues[c("SUBL_ID", "maizeResidues_t")]

households <- readRDS("outputs/01_supply/02_models/cropresidues/maizeHh.rds")
households <- households[c("SUBL_ID", "maizeHh")]

# Bring all together in one SPDF
all <- Reduce(function(x, y) merge(x, y, by = "SUBL_ID"), 
              list(subl, cropArea, yield, residues, households)); all
head(all)

saveRDS(all, "outputs/01_supply/02_models/cropresidues/allResults.rds")
writeOGR(obj = all[, !names(all) %in% "SUBL_ID"], 
         dsn = "outputs/01_supply/02_models/cropresidues/allResults.shp", 
         layer = "allResults", 
         driver = "ESRI Shapefile", 
         overwrite_layer = T)



# Density results --------------------------------------------------------------

# Import
all <- readRDS("outputs/01_supply/02_models/cropresidues/allResults.rds")

# Calculate density values (amount per sqkm) of results
perVar <- c("SUBL_ID_PaHC2009", "SUBL_ID", "Area_km2")
map <- all[, names(all) %in% perVar]
dta <- all[, !names(all) %in% perVar]@data
dta <- sapply(dta, function(x) x / all$Area_km2)
dens <- cbind(map, dta)

# Export
saveRDS(dens, "outputs/01_supply/02_models/cropresidues/allResults_dens.rds")
writeOGR(obj = dens[, !names(dens) %in% "SUBL_ID"], 
         dsn = "outputs/01_supply/02_models/cropresidues/allResults_dens.shp", 
         layer = "allResults", 
         driver = "ESRI Shapefile", 
         overwrite_layer = T)



# Check ------------------------------------------------------------------------

# Load data
agrHh <- readRDS("outputs/01_supply/01_inputs/agricHh.rds")
crMap <- readRDS("outputs/01_supply/02_models/cropresidues/allResults.rds")
crMap <- merge(crMap, agrHh[, c("SUBL_ID", "agricHh")])
crDta <- tbl_df(crMap); crDta
crAgg <- crDta %>% 
  summarise_at(vars(Area_km2:agricHh), funs(sum)) 
crAgg

# Agric area per hh
plotSize_ha <- crAgg$cropArea_km2 / crAgg$agricHh * 100; plotSize_ha 
# -> Ok:
#     - Ehrensperger 2013: ~2.5 ha, 
#     - IHBS2005: ~ 1.7ha

# Yield per household
crAgg$maizeYield_tHh <- crAgg$maizeYield_t / crAgg$agricHh; 
crAgg$maizeYield_tHh

# Maize yield
crAgg$maizeYield_t # Correct

# Yield to residue factor
crAgg$yieldToResidueRatio <- crAgg$maizeResidues_t / crAgg$maizeYield_t;
crAgg$yieldToResidueRatio # Correct

# Annual maize cob demand per year
crAgg$maizDem_tYrHh <- crAgg$maizeResidues_t / crAgg$maizeHh; 
crAgg$maizDem_tYrHh # Correct

# Maize production per ha (County Government of Kitui 2014)
m2013_ha <- 93600
m2013_bags <- 427347
m2013_tonnes <- m2013_bags * 90 / 1000; m2013_tonnes
m2013_tHa <- m2013_tonnes / m2013_ha; m2013_tHa 

m2012_ha <- 87970
m2012_bags <- 519000
m2012_tonnes <- m2012_bags * 90 / 1000; m2012_tonnes
m2012_tHa <- m2012_tonnes / m2012_ha; m2012_tHa

# -> 500kg per ha seems very low 
#    - compare to 
#         - 1000kg and more (Omoyo 2015)
#         - 1000 - 1400 kg (http://www.factfish.com/statistic-country/kenya/maize%2C%20total%2C%20yield)
#         - Ministry of Agriculutre, Livestock, and Fisheries (2015):
#             2012: 77210 ha, 55238.04 t, 0.738 t/ha
#             2013: 93,600 ha, 37499.49 t, 0.414 t/ha
#             2014: 84,763 ha, 30584.88 t, 0.369 t/ha
#    - but I checked again and it seems correct !!!


# What's the average maize culivating area per household based on 
#  the total area under maize cultivation and the number of households?
maizeCultivationArea_ha <- 90000 # Ministry of Agriculture, Livestock and ..2015
maizeCultivationArea_haHh <- maizeCultivationArea_ha / crAgg$agricHh
maizeCultivationArea_haHh

# How much maize and cultivation area per household would be required to cover 
# its fuel demand?
deman_tHhYr <- 1.4235
productiviy_tHa <- 0.5 # ~
yieldRequirement_tYr <- deman_tHhYr / 15 * 100; yieldRequirement_tYr
agricAreaDemand_haHh <- 1.4235 / 0.5; agricAreaDemand_haHh

maizeCultivationArea_haHh
agricAreaDemand_haHh
# -> if a household would like to cover its maize cob demand, 
#    it would have to produce 6 times more maize


# Can a household cover its maize cob demand?
crAgg$maizeYield_tHh / agricAreaDemand_haHh


demandCoverage <- crAgg$maizeYield_tHh / yieldRequirement_tYr; demandCoverage
# -> a maize cultivating houshold can only cover 3% of what it would require
# for cooking

supply_t <- 0.5 * 1.7 / 3 * 0.15; supply_t
demand_t <- 1.4235; demand_t
supply_t / demand_t




# ------------------------------------------------------------------------------

rm(list = ls())






















