

###############################################################################-
# Jatropha oil model
###############################################################################-

# # Libraries
library(raster)
library(rgdal)
library(tidyverse)
library(labelled)
library(haven)
library(splitstackshape)


# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000)
rm(list = ls())
        


# Maize plots ------------------------------------------------------------------

# Import
subl <- readRDS("outputs/01_supply/01_inputs/shrCropArea.rds")
agrHh <- readRDS("outputs/01_supply/01_inputs/agricHh.rds")

# Average maize households per sublocation
subl$agrHh <- subl$cropArea_shrTot * sum(agrHh$agricHh)

saveRDS(subl, "outputs/01_supply/02_models/jatrohaoil/maizeHouseholds.rds")




# Plot borders -----------------------------------------------------------------

# Import
subl <- readRDS("outputs/01_supply/02_models/jatrohaoil/maizeHouseholds.rds")
maizeArea_km2Hh <- readRDS("outputs/01_supply/01_inputs/plotSize_2.rds")

# Calculat the plot boundary per household
boundary_kmHh <- sqrt(maizeArea_km2Hh) * 4; boundary_kmHh

# Calculate length of plot boundaries per sublocation
subl$plotBoundaries_km <- subl$agrHh * boundary_kmHh

# Export 
saveRDS(subl, "outputs/01_supply/02_models/jatrohaoil/plotBoundaries.rds")



# Hedges -----------------------------------------------------------------------

# Import
subl <- readRDS("outputs/01_supply/02_models/jatrohaoil/plotBoundaries.rds")
shrJatrophaHedge <- readRDS("outputs/01_supply/01_inputs/shrJatrophaHedge.rds")
shrJatrophaHedge

# Calcualte length of Jatropha hedges
subl$jatrHedges_km <- subl$plotBoundaries_km * shrJatrophaHedge

# Export 
saveRDS(subl, "outputs/01_supply/02_models/jatrohaoil/jatrophaHedges.rds")



# Seeds -----------------------------------------------------------------------

# Import
subl <- readRDS("outputs/01_supply/02_models/jatrohaoil/jatrophaHedges.rds")
jatrophaSeedProdRate <- 
  readRDS("outputs/01_supply/01_inputs/jatrophaSeedProdRate.rds")

# Calculate the amount of seeds based on the Jatropha hedges and production rate
subl$jatrophaSeeds_t <- subl$jatrHedges_km * jatrophaSeedProdRate

# Export
saveRDS(subl, "outputs/01_supply/02_models/jatrohaoil/jatrophaSeeds.rds")



# Meal equivalents -------------------------------------------------------------

# Import
subl <- readRDS("outputs/01_supply/02_models/jatrohaoil/jatrophaSeeds.rds")
jSeedsDemand <- readRDS("outputs/01_supply/01_inputs/jSeedsDemand.rds")

# Convert the Jatropha seeds to jatropha oil
subl$jatrophaHh <- 
  subl$jatrophaSeeds_t / jSeedsDemand["jSeeds_tHhYr"]

# Export
saveRDS(subl, "outputs/01_supply/02_models/jatrohaoil/jatrophaHh.rds")



# Result overview --------------------------------------------------------------
# Create a table with all relevant intermediate results

subl <- readRDS("outputs/sublocations_kenya.rds")
subl <- subl[subl$COUN_NM == "KITUI", ]
subl <- subl[c("SUBL_ID_PaHC2009", "SUBL_ID", "Area_km2", "pop", "nrHh")]

agricHh <- readRDS("outputs/01_supply/01_inputs/agricHh.rds")
agricHh <- agricHh[c("SUBL_ID", "agricHh")]

plots <- readRDS("outputs/01_supply/02_models/jatrohaoil/plotBoundaries.rds")
plots <- plots[c("SUBL_ID", "plotBoundaries_km")]

jHedges <- readRDS("outputs/01_supply/02_models/jatrohaoil/jatrophaHedges.rds")
jHedges <- jHedges[c("SUBL_ID", "jatrHedges_km")]

jatrSeeds <- readRDS("outputs/01_supply/02_models/jatrohaoil/jatrophaSeeds.rds")
jatrSeeds <- jatrSeeds[c("SUBL_ID", "jatrophaSeeds_t")]

jatrHh <- readRDS("outputs/01_supply/02_models/jatrohaoil/jatrophaHh.rds")
jatrHh <- jatrHh[c("SUBL_ID", "jatrophaHh")]

# Bring all together in one SPDF
all <- Reduce(function(x, y) merge(x, y, by = "SUBL_ID"), 
              list(subl, agricHh, plots, jHedges, jatrSeeds, jatrHh)); all
head(all)

saveRDS(all, "outputs/01_supply/02_models/jatrohaoil/allResults.rds")
writeOGR(all, "outputs/01_supply/02_models/jatrohaoil/allResults.shp", 
         "allResults", "ESRI Shapefile", overwrite_layer = T)



# Density results --------------------------------------------------------------

# Import
all <- readRDS("outputs/01_supply/02_models/jatrohaoil/allResults.rds")

# Calculate density values (amount per sqkm) of results
perVar <- c("SUBL_ID_PaHC2009", "SUBL_ID", "Area_km2")
map <- all[, names(all) %in% perVar]
dta <- all[, !names(all) %in% perVar]@data
dta <- sapply(dta, function(x) x / all$Area_km2)
dens <- cbind(map, dta)

# Export
saveRDS(dens, "outputs/01_supply/02_models/jatrohaoil/allResults_dens.rds")
writeOGR(dens, "outputs/01_supply/02_models/jatrohaoil/allResults_dens.shp", 
         "allResults", "ESRI Shapefile", overwrite_layer = T)



# Jatropha ---------------------------------------------------------------------

# Load data
joMap <- readRDS("outputs/01_supply/02_models/jatrohaoil/allResults.rds")
joDta <- tbl_df(joMap); joDta
joAgg <- joDta %>% 
  summarise_at(vars(Area_km2:jatrophaHh), funs(sum(., na.rm = TRUE)))
joAgg

# Share of households cultivating crops



# Plot boundaries and size per hh
joAgg$plotBoundaries_kmHh <- joAgg$plotBoundaries_km / joAgg$agricHh
joAgg$plotBoundaries_kmHh
joAgg$plotSize_km2Hh <-  (joAgg$plotBoundaries_kmHh / 4)^2
joAgg$plotSize_km2Hh # Correct

# Share of Jatropha hedges
joAgg$jatrophaShare <- joAgg$jatrHedges_km / joAgg$plotBoundaries_km # Correct 
joAgg$jatrophaShare # Correct

# Jatropha seed productivity
joAgg$seedProductivity_TPerKm <- joAgg$jatrophaSeeds_t / joAgg$jatrHedges_km
joAgg$seedProductivity_TPerKm # Correct

# Jatropha production per HH
joAgg$seedProd_tHh <-  joAgg$jatrophaSeeds_t / joAgg$agricHh 
joAgg$seedProd_tHh 
# Lower than in Ehrensperger 2013 
#  (between 0.5 and 1 ton of jatropha seeds every year from hedges)
#  - Can be explained by smaller plot size (Ehrensperter: 2.5 ha; me: 1.73 ha)
#    and the 50% border restriction. Taking both into accound the values 
#    would be similar

# Jatropha demand per HH
joAgg$jatrophaDemand_tHh <- joAgg$jatrophaSeeds_t / joAgg$jatrophaHh
joAgg$jatrophaDemand_tHh # Correct

# Can households cover their on demand for Jatropha ? 
joAgg$seedProd_tHh / joAgg$jatrophaDemand_tHh
# no, only 30 percent of it


# Does it make a difference to use Jatropha seeds or Jatropha oil
seedDemand_tYrHh <- 0.803; seedDemand_tYrHh #"http://www.jetcitystoveworks.com/faqs.html"
oilDemand_tYrHh <- 210 / 1000 / 1000 * 2.5 * 365; oilDemand_tYrHh
relationOilToSeed <- oilDemand_tYrHh / seedDemand_tYrHh; relationOilToSeed
relationsSeedToOilPressing <- 1 * 0.7* 0.34; relationsSeedToOilPressing
# -> the cooking demand for jatropha seeds is about the same whether Jatropha 
#    is used for cooking as oil or dirictly as seeds



# ---------------------
rm(list = ls())





























