
###############################################################################-
# Prepare fuel demand
###############################################################################-

# Libraries
library(raster)
library(rgdal)
library(tidyverse)
library(haven)
library(labelled)
library(formattable)
library(pbapply)
library(splitstackshape)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000, scipen = 9999)



# Comments ---------------------------------------------------------------------

# The median was used (instead of the mean) because there where many data errors
#   (outliers)



# Data prepartaion -------------------------------------------------------------

# Get and pre-process id table
id <- read_sav("inputs/ihbs2005/inputs/Section A Identification.sav"); id
lapply(id, val_labels)
id <- id %>% 
  transmute(dist_nr = remove_labels(district), 
            dist_name = to_character(district), 
            rurban = to_character(rurban), 
            id_hh = paste0(id_clust, "-", id_hh), 
            hhsize, 
            hhweight = weight)
id


# Load and pre_process energy table
energy <- read_sav("inputs/ihbs2005/inputs/section H2 Energy.sav"); energy
energy <- energy %>% 
  transmute(id_hh = paste0(id_clust, "-", id_hh), 
            fuelType_icode = to_character(icode),
            use12Months_h33 = to_character(h33), 
            purpose_h35 = to_character(h35), 
            unitUsed_h36 = to_character(h36), 
            quantUsed_h36a = as.numeric(to_character(h36a)), 
            unitWeight_h37 = as.numeric(to_character(h37)), 
            unitsUsed_h38a = as.numeric(to_character(h38a)), 
            unitOfUse_h38b = to_character(h38b))
energy



# Firewood ---------------------------------------------------------------------

# Convert values form purchased firewood into kg per year
energy_fwp <- energy %>% 
  filter(purpose_h35 != "cooking") %>% 
  filter(fuelType_icode  == "purchased firewood") %>% 
  mutate(fuelType_icode = recode(fuelType_icode, 
                                 "purchased firewood" = "firewood (kg)")) %>% 
  transmute(id_hh, 
            fuelType = fuelType_icode, 
            amount = quantUsed_h36a * unitWeight_h37 * 12) %>% 
  group_by(id_hh, fuelType) %>% 
  summarise(amount = sum(amount)) %>% 
  ungroup()
energy_fwp
median(energy_fwp[energy_fwp$amount != 0, ]$amount)
mean(energy_fwp[energy_fwp$amount != 0, ]$amount)
boxplot(energy_fwp$amount)


# Convert values from collected firewood into kg per year
energy_fwc <- energy %>% 
  filter(purpose_h35 == "cooking") %>% 
  filter(fuelType_icode %in% c("collected firewood")) %>% 
  mutate(fuelType_icode = recode(fuelType_icode, 
                                 "collected firewood" = "firewood (kg)")) %>% 
  transmute(id_hh, 
            fuelType = fuelType_icode, 
            amount = quantUsed_h36a * unitWeight_h37 * 12) %>% 
  group_by(id_hh, fuelType) %>% 
  summarise(amount = sum(amount)) %>% 
  ungroup()
energy_fwc
median(energy_fwc[energy_fwc$amount != 0, ]$amount)
mean(energy_fwc[energy_fwc$amount != 0, ]$amount)
boxplot(energy_fwc$amount)

# Combind purchased firewood and collected firewood into one categroy
energy_fw <- bind_rows(energy_fwc, energy_fwp)
energy_fw <- energy_fw %>% 
  group_by(id_hh, fuelType) %>% 
  summarise(amount = sum(amount))
median(energy_fw[energy_fw$amount != 0, ]$amount)
mean(energy_fw[energy_fw$amount != 0, ]$amount)
boxplot(energy_fw$amount)



# Animal waste -----------------------------------------------------------------

# Convert values from animal waste into kg per year
energy_animalw <- energy %>% 
  filter(purpose_h35 == "cooking") %>% 
  filter(fuelType_icode %in% c("animal waste (biomass residue)")) %>% 
  mutate(fuelType_icode = recode(fuelType_icode, 
                                 "animal waste (biomass residue)" = 
                                   "animal waste (kg)")) %>% 
  transmute(id_hh, 
            fuelType = fuelType_icode, 
            amount = quantUsed_h36a * unitWeight_h37 * 12) %>% 
  group_by(id_hh, fuelType) %>% 
  summarise(amount = sum(amount)) %>% 
  ungroup()
energy_animalw
median(energy_animalw[energy_animalw$amount != 0, ]$amount)
mean(energy_animalw[energy_animalw$amount != 0, ]$amount)
boxplot(energy_animalw$amount)



# Crop waste -------------------------------------------------------------------

# Convert values from crop waste into kg per year
energy_cropw <- energy %>% 
  filter(purpose_h35 == "cooking") %>% 
  filter(fuelType_icode %in% c("straw or stalk (biomass residue)")) %>% 
  mutate(fuelType_icode = recode(fuelType_icode, 
                                 "straw or stalk (biomass residue)" = 
                                   "straw or stalk (kg)")) %>% 
  transmute(id_hh, 
            fuelType = fuelType_icode, 
            amount = quantUsed_h36a * unitWeight_h37 * 12) %>% 
  group_by(id_hh, fuelType) %>% 
  summarise(amount = sum(amount)) %>% 
  ungroup()
energy_cropw
median(energy_cropw[energy_cropw$amount != 0, ]$amount)
mean(energy_cropw[energy_cropw$amount != 0, ]$amount)
boxplot(energy_cropw$amount)



# Charcoal ---------------------------------------------------------------------

# Convert all biomass fuels into kg 
energy_charc <- energy %>% 
  filter(purpose_h35 == "cooking") %>% 
  filter(fuelType_icode %in% c("charcoal" )) %>% 
  mutate(fuelType_icode = recode(fuelType_icode, 
                                 "charcoal" = "charcoal (kg)")) %>% 
  transmute(id_hh, 
            fuelType = fuelType_icode, 
            amount = quantUsed_h36a * unitWeight_h37 * 12) %>% 
  group_by(id_hh, fuelType) %>% 
  summarise(amount = sum(amount)) %>% 
  ungroup()
energy_charc
median(energy_charc[energy_charc$amount != 0, ]$amount)
mean(energy_charc[energy_charc$amount != 0, ]$amount)
boxplot(energy_charc$amount)



# Kersin and paraffin ----------------------------------------------------------

# Convert all kerosin and praffin into litres
energy_kp <- energy %>% 
  filter(purpose_h35 == "cooking") %>% 
  filter(fuelType_icode %in% c("kerosene/paraffin")) %>% 
  mutate(fuelType_icode = recode(fuelType_icode, 
                                 "kerosene/paraffin" = 
                                   "kerosene/paraffin (l)")) %>% 
  transmute(id_hh, 
            fuelType = fuelType_icode, 
            amount = unitsUsed_h38a * 12) %>%  
  group_by(id_hh, fuelType) %>% 
  summarise(amount = sum(amount)) %>% 
  ungroup()
energy_kp
median(energy_kp[energy_kp$amount != 0, ]$amount)
mean(energy_kp[energy_kp$amount != 0, ]$amount)
boxplot(energy_kp$amount)



# Gas and LPG ------------------------------------------------------------------

# Convert gas and LPG into 3kg cylindres
energy_gl <- energy %>% 
  filter(purpose_h35 == "cooking") %>% 
  filter(fuelType_icode %in% c("gas/lpg")) %>% 
  mutate(fuelType_icode = recode(fuelType_icode, 
                                 "gas/lpg" = "gas/lpg (kgCyl)")) %>% 
  transmute(id_hh, 
            fuelType = fuelType_icode, 
            unitsUsed_h38a, 
            unit = as.numeric(recode(unitOfUse_h38b, 
                                     "other" = "NA", 
                                     "0" = "NA", 
                                     "7" = "NA", 
                                     "15 kg cylinder" = "15",
                                     "13 kg cylinder" = "13",
                                     "12.5 kg cylinder" = "12.5", 
                                     "6 kg cylinder" = "6", 
                                     "3 kg cylinder" = "3"))) %>% 
  transmute(id_hh, fuelType, amount = unitsUsed_h38a * unit * 12) %>% 
  group_by(id_hh, fuelType) %>% 
  summarise(amount = sum(amount)) %>% 
  ungroup()
energy_gl
median(energy_gl[energy_gl$amount != 0, ]$amount, na.rm = T)
mean(energy_gl[energy_gl$amount != 0, ]$amount, na.rm = T)
boxplot(energy_gl$amount, na.rm = T)



# Electricity ------------------------------------------------------------------

# Convert electricity into watt pr year
energy_elec <- energy %>% 
  filter(purpose_h35 == "cooking") %>% 
  filter(fuelType_icode %in% c("electricity")) %>% 
  transmute(id_hh, 
            fuelType = recode(fuelType_icode, 
                              "electricity" = "electricity (W)"),
            amount = unitsUsed_h38a * 12) %>% 
  group_by(id_hh, fuelType) %>% 
  summarise(amount = sum(amount)) %>% 
  ungroup()
energy_elec
median(energy_elec[energy_elec$amount != 0, ]$amount, na.rm = T)
mean(energy_elec[energy_elec$amount != 0, ]$amount, na.rm = T)
boxplot(energy_elec$amount, na.rm = T)


# All fuels --------------------------------------------------------------------

# Put the fuel data back into one table
energy_all <- bind_rows(energy_fw, energy_animalw, energy_cropw, energy_charc,
                        energy_gl, energy_kp, energy_elec)
energy_all <- energy_all %>% 
  drop_na() %>% 
  spread(fuelType, amount, fill = 0) %>% 
  group_by(id_hh) %>% 
  summarise_all(sum) 
energy_all

# Join the fuel data to the households
energy_all <- inner_join(x = id, y = energy_all, by = "id_hh")

# Add household weight by replication the row number accoringly
energy_all$hhweight <- round(energy_all$hhweight)
energy_all <- expandRows(dataset = energy_all, count = "hhweight")
energy_all$id <- row.names(energy_all)
saveRDS(energy_all, "outputs/02_demand/01_currCons/ihbs2005_preproc.rds")









