


###############################################################################-
# Prepare input data for demand
###############################################################################-

# Libraries
library(raster)
library(rgdal)
library(rgeos)


# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000)


# Extent -----------------------------------------------------------------------
targetCrs <- readRDS("inputs/crs/targedCrs.rds")


# CRS --------------------------------------------------------------------------
ext <- readRDS("inputs/extent/extent_country.rds")
ext <- spTransform(ext, targetCrs)


# Mask -------------------------------------------------------------------------
maskR <- raster("outputs/03_gravity/01_inputs/maskRaster_fac2.grd")


# Population -------------------------------------------------------------------
# Create layer with sublocations the population and the population density

# Load data, join population data, and reduce variables 
subl <- readRDS("inputs/pahc2009/01_prepareData/shp_joinReady.rds")
dta <- read.csv("inputs/PopulationKenya/data/data.txt", stringsAsFactors = F)
dta <- dta[, c("SL_ID", "SLPopP11A020")]
subl <- merge(subl, dta, by.x = "SUBL_ID", by.y = "SL_ID")
subl <- subl[, c("SUBL_ID", "SUBL_ID_PaHC2009", "Area_km2", "SLPopP11A020")]
names(subl)[names(subl) == "SLPopP11A020"] <- "pop"

# Compute population density
subl$popDens_popKm2 <- subl$pop / subl$Area_km2 

# Reproject layer
subl <- spTransform(subl, targetCrs)

# Limit to area of interest
subl <- intersect(x = subl, y = ext)

# Export
saveRDS(subl, "outputs/03_gravity/01_inputs/population.rds")


# LULC -------------------------------------------------------------------------
# Reduce LULC layer to given extent and reporject it to given CRS

# Load and crop
lulc <- raster(x = paste0("inputs/lulc/Globcover2009_V2.3_Global_/", 
                          "/GLOBCOVER_L4_200901_200912_V2.3.tif"))
lulc <- crop(lulc, spTransform(ext, lulc@crs))
lulc <- mask(lulc, spTransform(maskSp, lulc@crs))

writeRaster(lulc, "outputs/03_gravity/01_inputs/lulc.tif")

# Assign walking speed (km/h) according to the lulc type
# file.edit("input/ke/parameters/speedLulc.csv") 
speedClassesLulc <- read.csv("inputs/parameters/speedLulc.csv")
speedClassesLulc
lulc_speed <- subs(lulc, speedClassesLulc, "class", "speed")

# Aggregate, project, and mask
lulc_speed <- aggregate(x = lulc_speed, fact = 2, fun = mean)
lulc_speed <- projectRaster(lulc_speed, crs = maskR@crs, method = "bilinear")
lulc_speed <- crop(lulc_speed, maskR)
lulc_speed <- mask(lulc_speed, maskR)

# Export
writeRaster(
  lulc_speed, 
  "outputs/03_gravity/01_inputs/lulc_speed.grd", overwrite = T)
writeRaster(
  lulc_speed, 
  "outputs/03_gravity/01_inputs/lulc_speed.tif", overwrite = T)



# DEM --------------------------------------------------------------------------
# Reduce DEM to given extent, and reporject and resample it to given CRS

# Get all dem tiles and merge them
files <- list.files(path = "inputs/dem", 
                    recursive = T, 
                    pattern = "*tif$", 
                    full.names = T)
files <- lapply(files, raster)
dem <- do.call(merge, files)

# Crop, project, and resample layer (to LULC layer resolution)
dem <- crop(dem, spTransform(ext, dem@crs))
dem <- projectRaster(dem, maskR, method = "bilinear")
dem <- mask(dem, maskR)

# Export
writeRaster(dem, "outputs/03_gravity/01_inputs/dem.grd", overwrite = T)
writeRaster(dem, "outputs/03_gravity/01_inputs/dem.tif", overwrite = T)

# Slope
slope <- terrain(dem, opt = "slope")
writeRaster(slope, "outputs/03_gravity/01_inputs/slope.grd", overwrite = T)
writeRaster(slope, "outputs/03_gravity/01_inputs/slope.tif", overwrite = T)

# Hillshade 
aspect <- terrain(dem, opt = "aspect" )
hillShd <- hillShade(slope, aspect, direction = 315)
writeRaster(hillShd, "outputs/03_gravity/01_inputs/hillShade.grd", 
            overwrite = T)
writeRaster(hillShd, "outputs/03_gravity/01_inputs/hillShade.tif", 
            overwrite = T)



# Roads ------------------------------------------------------------------------

# Load, crop, and project layer 
roads <- readOGR(dsn = "inputs/roads/roads.shp", layer = "roads")
roads <- spTransform(roads, targetCrs)

# Clip geometires to area of interest
roads <- crop(roads, ext)

saveRDS(roads, "outputs/03_gravity/01_inputs/spRoads.rds")
writeOGR(roads, "outputs/03_gravity/01_inputs/roads.shp", "roads", 
         "ESRI Shapefile", overwrite_layer = T)

# Create stack with layers for each road type
# Define function for conversion    
# Input: waterw type in "type" attribute of "road" layer (string)  
# 1) Select select water way type
# 2) Check whether layer contains at least one feature
# 3) If it is the case: rasterize polylines add to stack, and name layer 
# Output: stack with layers layer with 1 if road existent

r <- read.csv("inputs/parameters/speedRoads_v02_reduction.csv")
roads <- roads[roads$type %in% r$class, ]
typesRoads <- levels(factor(unique(roads$type)))
sRoads <- stack(maskR); sRoads <- dropLayer(sRoads, 1) 
rasterizeRoads <- function(x){
  tmp <- subset(roads, type == x)
  if(length(tmp) != 0) { 
    print(x)
    sRoads <<- addLayer(sRoads, rasterize(tmp, maskR, 1))
    names(sRoads)[length(names(sRoads))] <<- x
  }
}
for (x in typesRoads){rasterizeRoads(x)}
roads <- sRoads
roads <- mask(roads, maskR)
writeRaster(roads, "outputs/03_gravity/01_inputs/roads.grd")
writeRaster(roads, "outputs/03_gravity/01_inputs/roads.tif")



# Waterways --------------------------------------------------------------------

# Load, crop, and project layer 
waterw <- readOGR(dsn = "inputs/waterways/waterways.shp", layer = "waterways")

# Clip geometires to area of interest
waterw <- spTransform(waterw, targetCrs)
waterw <- crop(waterw, ext)
saveRDS(waterw, "outputs/03_gravity/01_inputs/spWaterways.rds")
writeOGR(waterw, "outputs/03_gravity/01_inputs/waterw.shp", "waterw", 
         "ESRI Shapefile", overwrite_layer = T)

# Create stack with layer for each waterway type
# Define function for conversion    
# Input: waterw type in "type" attribute of "waterw" layer (string)  
# 1) Select select water way type
# 2) Check whether layer contains at least one feature
# 3) If it is the case: rasterize polylines add to stack, and name layer 
# Output: stack with layers layer with 1 if waterway existent
r <- read.csv("inputs/parameters/speedWaterw.csv")
waterw <- waterw[waterw$type %in% r$class, ]
typesWaterw <- levels(factor(unique(waterw$type)))

sWaterw <- stack(maskR); sWaterw <- dropLayer(sWaterw, 1) 
rasterizeWaterw <- function(x){
  tmp <- subset(waterw, type == x)
  if(length(tmp) != 0) { 
    print(x)
    sWaterw <<- addLayer(sWaterw, rasterize(tmp, maskR, 1))
    names(sWaterw)[length(names(sWaterw))] <<- x
  }
}
for (x in typesWaterw){rasterizeWaterw(x)}
waterw <- sWaterw 
waterw <- mask(waterw, maskR)
writeRaster(waterw, "outputs/03_gravity/01_inputs/waterways.grd")
writeRaster(waterw, "outputs/03_gravity/01_inputs/waterways.tif")



rm(list = ls())












