

###############################################################################.
# Compute gravity layer
#   - Based on the conductance layer and population data compute 
#     the population gravity
# Outputs: 
# - Gravity layer for all of Kenya 
#   (gravityRasterKenya_*_.grd)
# - Gravity layer with demand from Kitui County only 
#   (gravityRasterKitui_*_.grd)
# - Gravity layer with demand from outside Kitui County only 
#   (gravityRasterNonkitui_*_.grd)
###############################################################################.

# Libraries
library(gdistance)
library(SpatialPosition)
library(rgeos)
library(rgdal)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 200)
options(scipen = 999)

# Decay function: 
#   http://www.evernote.com/l/ATUiq2gXm6lKAbv4U7pqq4_sH1gUCCQF0pI/




# Define function 
createGravityBalance <- function(demVar = "nrHh",
                                 decayFnc = "exponential", 
                                 bta = 2, 
                                 spn = 5400){

  # Prepare filename
  flsNm <-  paste0("outputs/03_gravity/04_gravitiyLayers/results_", 
                   demVar, "_", 
                   decayFnc, "_", 
                   as.character(spn), "_", 
                   as.character(bta))
  print(paste0("Start: ", flsNm, "..."))
  
  
  
  # Data -----------------------------------------------------------------------
  print("Data... ")
  
  # Load data
  subloc_pts_all <- 
    readRDS("outputs/03_gravity/03_distanceMatrix/subloc_pts.rds")
  grd <- readRDS("outputs/03_gravity/03_distanceMatrix/grd_4000.rds")
  dm_cd <- readRDS(
    "outputs/03_gravity/03_distanceMatrix/distMatr_costDist_4000.rds")
  subloc <- readRDS("outputs/03_gravity/01_inputs/population.rds")
  
  # Get ID of sublocations in Kitui County
  sublKit <- readRDS("inputs/pahc2009/01_prepareData/shp_joinReady.rds")
  sublKit <- sublKit[sublKit$COUN_NM == "KITUI", ]$SUBL_ID_PaHC2009
    
  # Join fuel data to points
  dta <- readRDS("outputs/02_demand/01_currCons/pahc2009mainFuel_hh.rds")
  dta <- dta@data
  subloc_pts_all <- merge(x = subloc_pts_all[, c("SUBL_ID_PaHC2009")], 
                          y = dta, 
                          by = "SUBL_ID_PaHC2009", 
                          all.x = T)
  rm(list = c("dta"))
  
  
  
  # Cost distance gravity Kenya ------------------------------------------------
  print("Gravity Kenya ...")
  
  # Create demand gravity layer for Kenya
  gravityKenya <- stewart(knownpts = subloc_pts_all, 
                          unknownpts = grd, 
                          matdist = dm_cd, 
                          varname = demVar, 
                          typefct = decayFnc, 
                          span = spn, 
                          beta = bta, 
                          mask = subloc)
  gravityRasterKenya <- rasterStewart(x = gravityKenya, mask = NULL)
  rm(list = c("gravityKenya"))
  
  # Export
  path_kenya <- paste0(flsNm, "gravityRasterKenya", "_", ".grd")
  writeRaster(x = gravityRasterKenya,
              filename = path_kenya, 
              overwrite = T)
  rm(list = c("gravityRasterKenya"))

  
  
  # Cost distance gravity Kitui ------------------------------------------------
  print("Gravity Kitui ...")  
  
  # Set demand values outside Kitui to 0
  subloc_pts_ki <- subloc_pts_all
  subloc_pts_ki[!(subloc_pts_ki$SUBL_ID_PaHC2009 %in% sublKit), demVar] <- 0 
  
  # Create demand gravity layer for Kitui
  gravityKitui <- stewart(knownpts = subloc_pts_ki, 
                          unknownpts = grd, 
                          matdist = dm_cd, 
                          varname = demVar, 
                          typefct = decayFnc, 
                          span = spn, 
                          beta = bta, 
                          mask = subloc)
  gravityRasterKitui <- rasterStewart(x = gravityKitui, mask = NULL)
  rm(list = c("gravityKitui"))
  
  # Export
  path_kitui <- paste0(flsNm, "gravityRasterKitui", "_", ".grd")
  writeRaster(x = gravityRasterKitui, 
              filename = path_kitui, 
              overwrite = T)
  rm(list = c("gravityRasterKitui"))
  

    
  # Cost distance gravity nonKitui ---------------------------------------------
  print("Gravity non-Kitui ...")

  # Set demand values outside Kitui to 0
  subloc_pts_nk <- subloc_pts_all
  subloc_pts_nk[subloc_pts_nk$SUBL_ID_PaHC2009 %in% sublKit, demVar] <- 0

  # Create demand gravity layer for Kitui
  gravityNonkitui <- stewart(knownpts = subloc_pts_nk,
                          unknownpts = grd,
                          matdist = dm_cd,
                          varname = demVar,
                          typefct = decayFnc,
                          span = spn,
                          beta = bta,
                          mask = subloc)
  gravityRasterNonkitui <- rasterStewart(x = gravityNonkitui, mask = NULL)
  rm(list = c("gravityNonkitui"))

  # Export
  path_nonkitui <- paste0(flsNm, "gravityRasterNonkitui", "_", ".grd")
  writeRaster(x = gravityRasterNonkitui,
              filename = path_nonkitui,
              overwrite = T)
  rm(list = c("gravityRasterNonkitui"))
  
  
  
  # Clean ----------------------------------------------------------------------
  print("Difference layers ...")
  
  # Load raster layers  
  gravityRasterKenya <- raster(path_kenya)
  names(gravityRasterKenya) <- "ken"
  gravityRasterKitui <- raster(path_kitui)
  names(gravityRasterKitui) <- "kit"
  gravityRasterNonkitui <- raster(path_nonkitui)
  names(gravityRasterNonkitui) <- "nki"
  
  # Write to brick
  res <- brick(gravityRasterKenya, 
               gravityRasterKitui,
               gravityRasterNonkitui,
               filename = paste0(flsNm, ".grd"))
  rm(list = c("gravityRasterKenya"))
  rm(list = c("gravityRasterKitui"))
  rm(list = c("gravityRasterNonkitui"))

  
  # Delete intermediate files
  file.remove(path_kenya)
  file.remove(paste0(substr(path_kenya, 1, nchar(path_kitui)-3), "gri"))
  file.remove(path_kitui)
  file.remove(paste0(substr(path_kitui, 1, nchar(path_kitui)-3), "gri"))
  file.remove(path_nonkitui)
  file.remove(paste0(substr(path_nonkitui, 1, nchar(path_nonkitui)-3), "gri"))

  
  # Aggregation ------
  
  # Aggregate the results to Sublocation level
  subl <- readRDS("outputs/sublocations_kenya.rds"); subl; head(subl)
  subl <- subl[, c("SUBL_ID_PaHC2009", "Area_km2", "nrHh")]
  res_mean <- raster::extract(x = res,
                              y = subl,
                              fun = mean, 
                              na.rm = T, 
                              sp = T, 
                              weights = T)
  
  
  # Non-adjusted ------
  
  # Calculate values per sqkm
  res_mean$ken_pSqkm <- res_mean$ken / res_mean$Area_km2
  res_mean$kit_pSqkm <- res_mean$kit / res_mean$Area_km2
  res_mean$nki_pSqkm <- res_mean$nki / res_mean$Area_km2
  
    # Calculate share of kitui
  res_mean$demShrKit_nonAdj <- res_mean$kit / res_mean$ken
  res_mean$demShrKit_nonAdj[is.nan(res_mean$demShrKit_nonAdj)] <- 0 
                                            # Correct NaN due to division by 0
    # Correct 
  if(spn == 0){
    sublKit <- readRDS("inputs/pahc2009/01_prepareData/shp_joinReady.rds")
    sublKit <- sublKit[sublKit$COUN_NM == "KITUI", ]$SUBL_ID_PaHC2009
    res_mean[res_mean$SUBL_ID_PaHC2009 %in% sublKit, "demShrKit_nonAdj"] <- 1
    res_mean[!(res_mean$SUBL_ID_PaHC2009 %in% sublKit), "demShrKit_nonAdj"] <- 0
  }



  # Values for sublocations in Kitui County ---------------

  # Calulate the total gravity pressure within kitui county
  #   originating from outside kitui county
  pressInKitFromNonKit <-
    sum(res_mean[(res_mean$SUBL_ID_PaHC2009 %in% sublKit), ]$nki, na.rm = T)

  # Calulate the total gravity pressure outside kitui county
  #   originating from kitui county
  pressInKitFromKit <-
    sum(res_mean[(res_mean$SUBL_ID_PaHC2009 %in% sublKit), ]$kit, na.rm = T)

  # Calulate the total gravity pressure outside kitui county
  #   originating from Kenya
  pressInKitFromKen <-
    sum(res_mean[(res_mean$SUBL_ID_PaHC2009 %in% sublKit), ]$ken, na.rm = T)

  # Check
  pressInKitFromNonKit + pressInKitFromKit == pressInKitFromKen

  # Calculate relation between internal and external pressure
  shrInKitFromKit <- pressInKitFromKit / pressInKitFromKen
  


  # Values for sublocations outside Kitui County ---------------

  # Calulate the total gravity pressure outside kitui county
  #   originating from kitui county
  pressOutKitFromKit <-
    sum(res_mean[!(res_mean$SUBL_ID_PaHC2009 %in% sublKit), ]$kit, na.rm = T)

  # Calulate the total gravity pressure outside kitui county
  #   originating from outsite kitui county
  pressOutKitFromNonKit <-
    sum(res_mean[!(res_mean$SUBL_ID_PaHC2009 %in% sublKit), ]$nki, na.rm = T)


  # Calulate the total gravity pressure outside kitui county
  #   originating from both
  pressOutKitFromKen <-
    sum(res_mean[!(res_mean$SUBL_ID_PaHC2009 %in% sublKit), ]$ken, na.rm = T)

  # Check
  pressOutKitFromNonKit + pressOutKitFromKit == pressOutKitFromKen

  # Calculate relation between internal and external pressure
  shrOutKitFromKit <- pressOutKitFromKit / pressOutKitFromKen
  ifelse(is.nan(shrOutKitFromKit), 1, shrOutKitFromKit)
  corrFactor <- shrOutKitFromKit
  
  
  ## Reduce sublocations to Kitui County
  # res_mean <- res_mean[res_mean$SUBL_ID_PaHC2009 %in% sublKit, ]
  
  # Resuce share of Kitui by the correction factor
  res_mean$demShrKit <- res_mean$demShrKit_nonAdj - corrFactor
  res_mean$demShrKit <- ifelse(res_mean$demShrKit < 0, 0, res_mean$demShrKit)
  

  # Export result
  saveRDS(res_mean, 
          paste0(flsNm, ".rds"))
  writeOGR(res_mean, 
           paste0(flsNm, ".shp"), 
           rev(strsplit(flsNm, split = "/")[[1]])[1], 
           "ESRI Shapefile", 
           overwrite_layer = T)
  
}






















