
###############################################################################.
# Analys cut-off balance
###############################################################################.

# Libraries
library(raster)
library(tidyverse)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 200)
options(scipen = 999)



# ------------------------------------------------------------------------------

# Load data
subl <- readRDS("outputs/sublocations_kenya.rds")
subl_ids <- subl[subl$COUN_NM == "KITUI", ]$SUBL_ID_PaHC2009
kituiDemShr <- readRDS("outputs/04_balance/02_national/kituiDemShr.rds")
kituiDemShr <- kituiDemShr[kituiDemShr$SUBL_ID_PaHC2009 %in% subl_ids, ]
locDemKit <- readRDS("outputs/02_demand/02_demand/locDemKit.rds")
locSupKit <- readRDS("outputs/01_supply/03_results/allMealSupplies.rds")

# Calculate the balance of each decay model output
calcBalances <- function(decParam){
  
  # Create a SPDF with the different supplies (per fuel type and 
  # the supply share value)
  subl <- cbind(locSupKit[c("charcoalHh", "firewoodHh", "biogasHh", 
                            "jatrophaHh", "maizeHh")],
                kituiDemShr[[decParam]], 
                locDemKit["nrHh"])
  names(subl) <- c("sup_charcoal_hh", "sup_firewood_hh", 
                   "sup_biogas_hh", "sup_jatropha_hh", "sup_maize_hh", 
                   "supAvailablity_shr", "dem_int_hh")
  
  # Graphical overview for the following attributes
  # http://www.evernote.com/l/ATWtmrUKLU5Lk6TTo6pR8Lr7mHwEFawyRFE/
  
  # Caluclate demand (demand line)
  subl$dem_int_hh <- subl$dem_int_hh
  
  # Calucalte total demand pressure 
  subl$dem_tot_hh <- subl$dem_int_hh / subl$supAvailablity_shr 
  
  # Caluclate external demand pressure
  subl$dem_ext_hh <- 
    subl$dem_int_hh / subl$supAvailablity_shr * (1 - subl$supAvailablity_shr)
  
  # Calculate the total supply 
  subl$sup_tot_hh <- 
    subl$sup_charcoal_hh + subl$sup_firewood_hh + subl$sup_biogas_hh + 
    subl$sup_jatropha_hh + subl$sup_maize_hh
  
  # Calculatet the supply destined for local (with kitui) consumption (shr line)
  subl$sup_shrLine <- subl$sup_tot_hh * subl$supAvailablity_shr
  
  # Calculate the supply of tranportable fuels (T)
  subl$sup_tf_hh <- 
    subl$sup_firewood_hh + subl$sup_charcoal_hh + subl$sup_jatropha_hh
  
  # Calcualte the supply of non-transportable fuels (NT)
  subl$sup_ntf_hh <- 
    subl$sup_biogas_hh + subl$sup_maize_hh
  
  # Calculate cut-off
  subl$sup_cutoff_hh <- 
    ifelse(
      test = subl$sup_ntf_hh > subl$dem_int_hh, 
      yes = subl$sup_ntf_hh - subl$dem_int_hh, 
      no = 0
    )
  
  # Calculate the surplus (will be compensating sublocations within the county)
  subl$sup_surplus_hh <- 
    ifelse(
      test = subl$sup_shrLine > subl$dem_int_hh & 
        subl$sup_ntf_hh < subl$sup_shrLine,
      yes = ifelse(
        test = subl$sup_ntf_hh > subl$dem_int_hh,
        yes = subl$sup_shrLine - subl$sup_ntf_hh,
        no = subl$sup_shrLine - subl$dem_int_hh
      ),
      no = 0
    )
  
  # Caluclate the exported supply
  subl$sup_exp_hh <- 
    ifelse (
      test = subl$sup_tf_hh > (subl$sup_tot_hh - subl$sup_shrLine),
      yes = subl$sup_tot_hh - subl$sup_shrLine, 
      no = subl$sup_tot_hh - subl$sup_ntf_hh
    )
  
  # Calculate the deficit
  subl$sup_deficit_hh <- 
    ifelse(
      test = subl$sup_shrLine < subl$dem_int_hh,
      yes = ifelse(
        test = subl$sup_ntf_hh < subl$sup_shrLine,
        yes = subl$dem_int_hh - subl$sup_shrLine,
        no = ifelse(
          test = subl$sup_ntf_hh < subl$dem_int_hh, 
          yes = subl$dem_int_hh - subl$sup_ntf_hh, 
          no = 0
        )
      ),
      no = 0
    )
  
  # Calculate the local consumptions
  subl$sup_loc_cons_hh <- 
    ifelse(
      test = subl$sup_shrLine < subl$dem_int_hh & 
        subl$sup_ntf_hh < subl$dem_int_hh,
      yes = ifelse(
        test = subl$sup_ntf_hh < subl$sup_shrLine,
        yes = subl$sup_shrLine, 
        no = subl$sup_ntf_hh
      ),
      no = subl$dem_int_hh
    )
  
  # Calculate the balance
  subl$balance_hh <- 
    (subl$sup_loc_cons_hh + subl$sup_surplus_hh) - subl$dem_int_hh
  
  
  # # Test 1 --- 
  # # The local consumption, export, cutoff and surplus should equal the total 
  # # supply
  # test <- 
  #   subl$sup_loc_cons_hh + 
  #   subl$sup_exp_hh + 
  #   subl$sup_surplus_hh + 
  #   subl$sup_cutoff_hh
  # all(round(subl$sup_tot_hh) == round(test))
  
  return(subl)
}
balRes_ls <- 
  sapply(names(kituiDemShr)[2:length(names(kituiDemShr))], calcBalances)
balRes_ls
saveRDS(balRes_ls, "outputs/04_balance/02_national/balance_alt.rds")



# -------------------------------------

# Aggregate (sum) results and bring them to one single DF for comparison
compareModels <- function(x){
  print(x)
  dta <- tbl_df(x@data)
  dta2 <- dta %>%
    summarise_at(vars(-supAvailablity_shr),
                 funs(sum)) %>%
    mutate(bal = sup_surplus_hh - sup_deficit_hh)
  dta3 <- dta %>% 
    summarise(supAvailablity_shr =  weighted.mean(supAvailablity_shr, 
                                                  sup_tot_hh))
  dta <- cbind(dta2, dta3)
}
balComp_l <- sapply(balRes_ls, compareModels, simplify = F, USE.NAMES = F)
balComp_m <- do.call(rbind, lapply(balComp_l, unlist))
balComp_df <- tbl_df(data.frame(model = rownames(balComp_m),  balComp_m, 
                                row.names = NULL, 
                                stringsAsFactors = F))
balComp <- balComp_df %>% 
  separate(model, into = c("dummy", "version",  "varname", "typefct", "span",
                           "beta"), 
           sep = "_") %>% 
  select(-dummy, -version) %>% 
  mutate(span = as.integer(span))
balComp <- balComp %>% arrange(span)
balComp
saveRDS(balComp, "outputs/04_balance/02_national/balance_comparison_alt.rds")

