

###############################################################################.
# Remote balance
###############################################################################.

# Libraries
library(raster)
library(rgdal)
library(rgeos)
library(gridExtra)
library(tidyverse)
library(scales)
library(lubridate)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 200)
options(scipen = 999)



# Deacay impact on fuel supply: No cut-off and fw non-transportable ------------


# Load data
balRes <- readRDS("outputs/04_balance/02_national/balance.rds")
balRes
balComp <- 
  readRDS("outputs/04_balance/02_national/balance_comparison.rds")
balComp
source("scripts/prepareFuelColors.R"); colrsFuels


# Prepare table for plotting
dta <- balComp
dta_a <- balComp %>%
  gather(variable, value, sup_charcoal_hh:sup_maize_hh) %>% 
  mutate(variable = recode(variable, 
                           sup_charcoal_hh = "Charcoal", 
                           sup_firewood_hh = "Firewood", 
                           sup_biogas_hh  = "Biogas", 
                           sup_maize_hh = "Maize cobs", 
                           sup_jatropha_hh = "Jatropha"))
dta_a


# Plot the relation between the decay function and global balance
plot_a <- 
  ggplot(dta_a, mapping = aes(x = span, 
                              y = value, 
                              fill = factor(variable, levels = c("Jatropha",
                                                                 "Charcoal",
                                                                 "Maize cobs",
                                                                 "Biogas",
                                                                 "Firewood"))))+
  geom_area(stat="identity") +     
  geom_hline(yintercept = dta_a[[1, "dem_int_hh"]], color = "black") +
  geom_text(aes(x = 0, y = dta_a[[1, "dem_int_hh"]], 
                label = paste("Demand: ", comma(round(dta_a[[1, "dem_int_hh"]], -3))), 
                vjust = -0.5, hjust = -5), 
            size = 3) + 
  ggtitle(label = paste0("Composition of biomass cooking fuels supply", 
                         "within Kitui County")) +
  scale_fill_manual(name = "Fuels", 
                    values = colrsFuels, 
                    breaks = names(colrsFuels)) +
  scale_y_continuous(name = "Balance\n (Households)", 
                     labels = comma, 
                     expand = c(0.0,0.0),
                     limits = c(0, 600000)) +
  scale_x_continuous(name = "Span \n (minutes)",
                     breaks = seq(from = 0,
                                  to = 18000,
                                  by = 900), 
                     expand = c(0, 0)) +
  theme(
    panel.border = element_rect(fill = NA),
    panel.background = element_rect(fill = "white"),
    panel.grid.major = element_line(colour = "grey"), 
    legend.key =  element_blank(),
    axis.ticks = element_blank()
  ); plot_a

# Export plot
# ggsave(
#   filename = "outputs/05_maps/distDecyImpact_cutoff.png",
#   width = 6, height = 3, dpi = 300, scale = 1)




# Demand and supply under different internal exchange scenarios ----------------


# Load data
balRes <- readRDS("outputs/04_balance/02_national/balance.rds")
balRes
balComp <- 
  readRDS("outputs/04_balance/02_national/balance_comparison.rds")
balComp
source("scripts/prepareFuelColors.R"); colrsFuels


# Prepare table for plotting
dta_b <- balComp %>% 
  select(span, dem_int_hh, sup_all_hh, bal_hh, bal_hh_fullcut, bal_hh_adj) %>% 
  transmute(span, 
            dem_int_hh, 
            sup_all_hh, 
            sup_hh = bal_hh + dem_int_hh, 
            sup_hh_fullcut = bal_hh_fullcut + dem_int_hh, 
            sup_hh_adj = bal_hh_adj + dem_int_hh) %>% 
  gather(sup_type, sup, sup_hh:sup_hh_adj)


# Plot the relation between the decay function and global balance
plot_b <- 
  ggplot(data = dta_b, mapping = aes(x = span/60, y = sup)) +
  geom_line(data = dta_b, 
            mapping = aes(colour = sup_type), 
            size = 1) +
  scale_color_discrete(name = "Supply \nunder different scenarios", 
                       breaks = levels(factor(dta_b$sup_type)), 
                       labels = c(sup_hh = "Internal exchange of all fuels", 
                                  sup_hh_adj = paste0("Internal exchange of ", 
                                                      "transportable fuels"), 
                                  sup_hh_fullcut = "No internal exchange")) + 
  scale_x_continuous(name = "External exchange \n(Span in minutes)",
                     breaks = seq(from = 0,
                                  to = max(dta_b$span),
                                  by = 1800/60),
                     expand = c(0.0,0.0),
                     labels = paste(seq(from = 0,
                                        to = max(dta_b$span),
                                        by = 1800/60))) +
  scale_y_continuous(name = "Households",
                     labels = comma,
                     expand = c(0.0,0.0),
                     limits = c(0, 600000),
                     # position = "right",
                     sec.axis = sec_axis(trans = ~ ( . / balComp$dem_int_hh[1]),
                                         labels = percent,
                                         breaks = seq(0, 3, 0.5),
                                         name = paste("Demand coverage\n"))) +
  geom_hline(aes(yintercept = dta_b$dem_int_hh[1], linetype = ""), 
             size = 1,
             color = "black") +
  scale_linetype_manual(name = "Demand",
                       values = c(1, 1),
                       guide = guide_legend(override.aes = 
                                              list(color = c("black")))) + 
  ggtitle(label = paste0("Demand and availabe supply of biomass cooking fuels ", 
                         "within Kitui County")) +
  theme(
    panel.border = element_rect(fill = NA),
    panel.background = element_rect(fill = "white"),
    panel.grid.major = element_line(colour = "grey"), 
    legend.key =  element_blank(),
    axis.ticks = element_blank()
  )
plot_b 

# Export plot
# ggsave(
#   filename = "outputs/05_maps/distDecyImpact.png",
#   width = 6, height = 3, dpi = 300, scale = 1)




# Balance under different internal exchange scenarios --------------------------


# Load data
balRes <- readRDS("outputs/04_balance/02_national/balance.rds")
balRes
balComp <- 
  readRDS("outputs/04_balance/02_national/balance_comparison.rds")
balComp
source("scripts/prepareFuelColors.R"); colrsFuels


# Prepare table for plotting
dta_c <- balComp %>% 
  select(span, bal_hh, bal_hh_fullcut, bal_hh_adj) %>% 
  gather(bal_type, bal, bal_hh:bal_hh_adj) 


# Plot the relation between the decay function and global balance
plot_c <- 
  ggplot(data = dta_c, mapping = aes(x = span/60, y = bal)) +
  geom_line(data = dta_c, 
            mapping = aes(colour = bal_type), 
            size = 1) +
  scale_color_discrete(name = "Internal exchange", 
                       breaks = levels(factor(dta_c$bal_type)), 
                       labels = c(bal_hh = "All fuels", 
                                  bal_hh_adj = "Only transportable fuels", 
                                  bal_hh_fullcut = "None")) + 
  scale_x_continuous(name = "External exchange \n(Span in minutes)",
                     breaks = seq(from = 0,
                                  to = max(dta_c$span),
                                  by = 1800/60),
                     expand = c(0.0,0.0),
                     labels = paste(seq(from = 0,
                                        to = max(dta_c$span),
                                        by = 1800/60))) +
  scale_y_continuous(name = "Balance (Households)",
                     labels = comma,
                     expand = c(0.0,0.0),
                     limits = c(-200000, 400000),
                     # position = "right",
                     sec.axis = sec_axis(trans = ~ 1 +( . / balComp$dem_int_hh[1]),
                                         labels = percent,
                                         breaks = seq(0, 3, 0.5),
                                         name = paste("Demand coverage\n"))) +
  geom_hline(mapping = aes(yintercept = 0), 
             size = 0.5,
             color = "black") +
  ggtitle(label = paste0("Demand-supply balance of biomass cooking fuels ", 
                         "within Kitui County")) +
  theme(
    panel.border = element_rect(fill = NA),
    panel.background = element_rect(fill = "white"),
    panel.grid.major = element_line(colour = "grey"), 
    legend.key =  element_blank(),
    axis.ticks = element_blank()
  )
plot_c

# Export plot
# ggsave(
#   filename = "outputs/05_maps/distDecyImpact.png",
#   width = 6, height = 3, dpi = 300, scale = 1)




